@@ -6,7 +6,7 @@ from formic_opcua import OpcuaClient
 
 # Configure asyncua library log level
 asyncua_logger = logging.getLogger('asyncua')
-asyncua_logger.setLevel(logging.CRITICAL)
+asyncua_logger.setLevel(logging.INFO)
 
 
 # Basic handler for opcua library
